==> faq-system-0.3.1.tar.gz: faq-system-0.3.1/getanswer.cc <==
#include "conf.h"

int main(void)
{
        //int i;
        char **tuple;
        Database *db;
        DBResult *res;

        db = new Database();

	cgi C;
        C.initPage();

	string instance;
        instance = C.get_value("instance");
        config CONF(instance);

	const char* MYDATABASE;
        const char* MYTOPIC;
        const char* MYANSWER;
        const char* MYQUESTION;
        MYDATABASE = CONF.MYDATABASE.c_str();
        MYTOPIC = CONF.MYTOPIC.c_str();
        MYANSWER = CONF.MYANSWER.c_str();
        MYQUESTION = CONF.MYQUESTION.c_str();

        // Initialise the database - for future releases
        if (db->init() != DB_COMMAND_OK) {
                fprintf(stdout, "Unable to initialize database: %s\n\n",
                        db->errorMessage());
                exit(1);
        }

        string stage, question, answer_id, question_id, topic_id, keys;
	string answer[10];
        int i, u;
	question_id = C.get_value("question_id");
	stage = C.get_value("stage");


	HTML h;
	
	cout << h.html() << h.body("#ffffff") << endl;


        if (db->init() != DB_COMMAND_OK) {
                fprintf(stdout, "Unable to initialize database: %s\n\n",
                        db->errorMessage());
                exit(1);
        }

                        // Connect to database on localhost
        if (db->connect("localhost", "", MYDATABASE) != DB_CONNECTION_OK) {
                fprintf(stdout, "Unable connect to database '%s': %s\n\n",
                        MYDATABASE, db->errorMessage());
                exit(1);
        } 

	res = db->exec("SELECT value FROM %s WHERE question_id = %s", MYQUESTION, question_id.c_str());
	tuple = res->getTuple();
	while (tuple != NULL)
        {
		cout << "<h1>" << *(tuple) << "</h1>" << endl;
                tuple = res->getTuple();
        } 

	db->exec(res, "SELECT value FROM %s WHERE question_id = %s", MYANSWER, question_id.c_str());
	tuple = res->getTuple();
	i=0;
	while (tuple != NULL)
        {
		answer[i] = *(tuple);
                tuple = res->getTuple();
                i++; 
        }

       	if (stage == "dbadmin")
       	{
		u=0;
       	        db->exec(res, "SELECT answer_id FROM %s WHERE question_id = %s", MYANSWER, question_id.c_str());
       	        tuple = res->getTuple();
       	        while (tuple != NULL)
       	        {
       	                cout << "<p><A HREF=\"" << URL << "/" << ADMIN ;
       	                cout << "/modify.cgi?instance=" << instance << "&stage=prepare&mode=answer&answer_id=" << *(tuple) ;
       	                cout << "\">[ modify ]</A><br>  " << answer[u++] << "</p><br>";
			tuple = res->getTuple();
       	        }
		
       	} 
	else
	{
		for(u=0;u<i;u++)
		{
			cout << "<p>\n";
			cout << answer[u];
			cout << "</p>\n";
		}
 	}
	Pro p; 
	if(stage == "dbadmin")
		cout << p.back("dbadmin", instance) << endl;
	else
		cout << p.back("user", instance) << endl;
	cout << h._body() << h._html() << endl;

}

==> faq-system-0.3.6.tar.gz: faq-system-0.3.6/getanswer.cc <==
#include "conf.h"

int main(void)
{
        //int i;
        char **tuple;
        Database *db;
        DBResult *res;

        db = new Database();

	cgi C;
        C.initPage();

	string instance;
        instance = C.get_value("instance");
        config CONF(instance);

	const char* MYDATABASE;
        const char* MYTOPIC;
        const char* MYANSWER;
        const char* MYQUESTION;
	const char* HOST;
        const char* USER;
        const char* PASS;
        HOST = CONF.HOST.c_str();
	USER = CONF.USER.c_str();
        PASS = CONF.PASS.c_str(); 
        MYDATABASE = CONF.MYDATABASE.c_str();
        MYTOPIC = CONF.MYTOPIC.c_str();
        MYANSWER = CONF.MYANSWER.c_str();
        MYQUESTION = CONF.MYQUESTION.c_str();

        // Initialise the database - for future releases
        if (db->init() != DB_COMMAND_OK) {
                fprintf(stdout, "Unable to initialize database: %s\n\n",
                        db->errorMessage());
                exit(0);
        }

        string stage, question, answer_id, question_id, topic_id, keys;
	string answer[10];
        int i, u;
	question_id = C.get_value("question_id");
	stage = C.get_value("stage");


	HTML h;
	
	cout << h.html() << h.body("#ffffff") << endl;


        if (db->init() != DB_COMMAND_OK) {
                fprintf(stdout, "Unable to initialize database: %s\n\n",
                        db->errorMessage());
                exit(0);
        }

                        // Connect to database on localhost
	if (db->connect(HOST, "", MYDATABASE, USER, PASS) != DB_CONNECTION_OK) { 
                fprintf(stdout, "Unable connect to database '%s': %s\n\n",
                        MYDATABASE, db->errorMessage());
                exit(0);
        } 

	res = db->exec("SELECT value FROM %s WHERE question_id = %s", MYQUESTION, question_id.c_str());
	tuple = res->getTuple();
	while (tuple != NULL)
        {
		cout << "<h1>" << *(tuple) << "</h1>" << endl;
                tuple = res->getTuple();
        } 

	db->exec(res, "SELECT value FROM %s WHERE question_id = %s", MYANSWER, question_id.c_str());
	tuple = res->getTuple();
	i=0;
	while (tuple != NULL)
        {
		answer[i] = *(tuple);
                tuple = res->getTuple();
                i++; 
        }

       	if (stage == "dbadmin")
       	{
		u=0;
       	        db->exec(res, "SELECT answer_id FROM %s WHERE question_id = %s", MYANSWER, question_id.c_str());
       	        tuple = res->getTuple();
       	        while (tuple != NULL)
       	        {
       	                cout << "<p><A HREF=\"" << URL << "/" << ADMIN ;
       	                cout << "/modify.cgi?instance=" << instance << "&stage=prepare&mode=answer&answer_id=" << *(tuple) ;
       	                cout << "\">[ modify ]</A> "; 
			cout << "<A HREF=\"" << URL << "/" << ADMIN << "/delete.cgi?instance=" << instance
                	<< "&stage=prepare&mode=answer&answer_id=" << *(tuple) << "\">[ delete ]</A><br><br>\n"
			<< answer[u++] << "</p><br>";
			tuple = res->getTuple();
       	        }
		
       	} 
	else
	{
		for(u=0;u<i;u++)
		{
			cout << "<p>\n";
			cout << answer[u];
			cout << "</p>\n";
		}
 	}
	Pro p; 
	if(stage == "dbadmin")
		cout << p.back("dbadmin", instance) << endl;
	else
		cout << p.back("user", instance) << endl;
	cout << h._body() << h._html() << endl;

}
